@@ -23,7 +23,6 @@
 #include "KonqMainWindowAdaptor.h"
 #include "konqmainwindow.h"
 #include "konqmainwindowfactory.h"
-#include "konqpreloadinghandler.h"
 #include "konqviewmanager.h"
 #include "konqview.h"
 #include "konqsettingsxt.h"
@@ -118,14 +117,29 @@ QList<QDBusObjectPath> KonquerorAdaptor::getWindows()
     return lst;
 }
 
+QStringList KonquerorAdaptor::urls() const
+{
+    QStringList lst;
+    QList<KonqMainWindow *> *mainWindows = KonqMainWindow::mainWindowList();
+    if (mainWindows) {
+        for (KonqMainWindow *window : *mainWindows) {
+            if (!window->isPreloaded()) {
+                for (KonqView *view : window->viewMap()) {
+                    lst.append(view->url().toString());
+                }
+            }
+        }
+    }
+    return lst;
+}
+
 QDBusObjectPath KonquerorAdaptor::windowForTab()
 {
     QList<KonqMainWindow *> *mainWindows = KonqMainWindow::mainWindowList();
     if (mainWindows) {
         foreach (KonqMainWindow *window, *mainWindows) {
             KWindowInfo winfo(window->winId(), NET::WMDesktop);
-            if (winfo.isOnCurrentDesktop() &&
-                    !KonqPreloadingHandler::self()->hasPreloadedWindow()) {  // we want a tab in an already shown window
+            if (winfo.isOnCurrentDesktop()) {  // we want a tab in an already shown window
                 Q_ASSERT(!window->dbusName().isEmpty());
                 return QDBusObjectPath(window->dbusName());
             }
