@@ -58,15 +58,15 @@ const int KonqCombo::temporary = 0;
 static QString titleOfURL(const QString &urlStr)
 {
     QUrl url(QUrl::fromUserInput(urlStr));
-    KonqHistoryList historylist = KonqHistoryManager::kself()->entries();
-    KonqHistoryList::iterator historyentry = historylist.findEntry(url);
-    if (historyentry == historylist.end() && !url.url().endsWith('/')) {
+    const KonqHistoryList &historylist = KonqHistoryManager::kself()->entries();
+    KonqHistoryList::const_iterator historyentry = historylist.constFindEntry(url);
+    if (historyentry == historylist.constEnd() && !url.url().endsWith('/')) {
         if (!url.path().endsWith('/')) {
             url.setPath(url.path() + '/');
         }
-        historyentry = historylist.findEntry(url);
+        historyentry = historylist.constFindEntry(url);
     }
-    return (historyentry != historylist.end() ? (*historyentry).title : QString());
+    return historyentry != historylist.end() ? (*historyentry).title : QString();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -74,7 +74,7 @@ static QString titleOfURL(const QString &urlStr)
 class KonqListWidgetItem : public QListWidgetItem
 {
 public:
-    enum ItemType { KonqItemType = 0x1845D5CC };
+    enum { KonqItemType = 0x1845D5CC };
 
     KonqListWidgetItem(QListWidget *parent = Q_NULLPTR);
     KonqListWidgetItem(const QString &text, QListWidget *parent = Q_NULLPTR);
@@ -103,7 +103,7 @@ class KonqComboLineEdit : public KLineEdit
 {
 public:
     KonqComboLineEdit(QWidget *parent = Q_NULLPTR);
-    void setCompletedItems(const QStringList &items, bool) Q_DECL_OVERRIDE;
+    KCompletionBox *completionBox(bool create) Q_DECL_OVERRIDE;
 
 protected:
     void mouseDoubleClickEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
@@ -114,7 +114,6 @@ class KonqComboCompletionBox : public KCompletionBox
 public:
     KonqComboCompletionBox(QWidget *parent);
     void setItems(const QStringList &items);
-    void insertStringList(const QStringList &list, int index = -1);
 };
 
 KonqCombo::KonqCombo(QWidget *parent)
@@ -367,15 +366,11 @@ void KonqCombo::loadItems()
 
     KConfigGroup locationBarGroup(s_config, "Location Bar");
     const QStringList items = locationBarGroup.readPathEntry("ComboContents", QStringList());
-    QStringList::ConstIterator it = items.begin();
-    QString item;
-    while (it != items.end()) {
-        item = *it;
+    for (const QString &item : items) {
         if (!item.isEmpty()) {   // only insert non-empty items
             insertItem(KonqPixmapProvider::self()->pixmapFor(item, KIconLoader::SizeSmall),
                        item, i++, titleOfURL(item));
         }
-        ++it;
     }
 
     if (count() > 0) {
@@ -676,37 +671,6 @@ void KonqCombo::setPageSecurity(int pageSecurity)
     }
 }
 
-bool KonqCombo::hasSufficientContrast(const QColor &c1, const QColor &c2)
-{
-    // Taken from khtml/misc/helper.cc
-#define HUE_DISTANCE 40
-#define CONTRAST_DISTANCE 10
-
-    int h1, s1, v1, h2, s2, v2;
-    int hdist = -CONTRAST_DISTANCE;
-    c1.getHsv(&h1, &s1, &v1);
-    c2.getHsv(&h2, &s2, &v2);
-    if (h1 != -1 && h2 != -1) { // grey values have no hue
-        hdist = qAbs(h1 - h2);
-        if (hdist > 180) {
-            hdist = 360 - hdist;
-        }
-        if (hdist < HUE_DISTANCE) {
-            hdist -= HUE_DISTANCE;
-            // see if they are high key or low key colours
-            bool hk1 = h1 >= 45 && h1 <= 225;
-            bool hk2 = h2 >= 45 && h2 <= 225;
-            if (hk1 && hk2) {
-                hdist = (5 * hdist) / 3;
-            } else if (!hk1 && !hk2) {
-                hdist = (7 * hdist) / 4;
-            }
-        }
-        hdist = qMin(hdist, HUE_DISTANCE * 2);
-    }
-    return hdist + (qAbs(s1 - s2) * 128) / (160 + qMin(s1, s2)) + qAbs(v1 - v2) > CONTRAST_DISTANCE;
-}
-
 void KonqCombo::slotReturnPressed()
 {
     slotActivated(currentText());
@@ -743,7 +707,7 @@ QVariant KonqListWidgetItem::data(int role) const
 
         if (!title.isEmpty()) {
             pixmap = provider->pixmapFor(text(), KIconLoader::SizeSmall);
-        } else if (text().indexOf(QLatin1String("://")) == -1) {
+        } else if (!text().contains(QLatin1String("://"))) {
             title = titleOfURL(QLatin1Literal("http://") + text());
             if (!title.isEmpty()) {
                 pixmap = provider->pixmapFor(QLatin1Literal("http://") + text(), KIconLoader::SizeSmall);
@@ -869,66 +833,18 @@ void KonqComboLineEdit::mouseDoubleClickEvent(QMouseEvent *e)
     KLineEdit::mouseDoubleClickEvent(e);
 }
 
-// KDE5 TODO: get rid of this duplicated code, and just reimplement completionBox()
-
-void KonqComboLineEdit::setCompletedItems(const QStringList &items, bool)
+KCompletionBox *KonqComboLineEdit::completionBox(bool create)
 {
-    QString txt;
-    KonqComboCompletionBox *completionbox = static_cast<KonqComboCompletionBox *>(completionBox());
-
-    if (completionbox && completionbox->isVisible())
-        // The popup is visible already - do the matching on the initial string,
-        // not on the currently selected one.
-    {
-        txt = completionbox->cancelledText();
-    } else {
-        txt = text();
+    KCompletionBox *box = KLineEdit::completionBox(false);
+    if (create && !box) {
+        KonqComboCompletionBox *konqBox = new KonqComboCompletionBox(this);
+        setCompletionBox(konqBox);
+        konqBox->setObjectName(QStringLiteral("completion box"));
+        konqBox->setFont(font());
+        return konqBox;
     }
 
-    if (!items.isEmpty() && !(items.count() == 1 && txt == items.first())) {
-        if (!completionBox(false)) {
-            setCompletionBox(new KonqComboCompletionBox(this));
-            completionbox = static_cast<KonqComboCompletionBox *>(completionBox());
-        }
-
-        if (completionbox->isVisible()) {
-
-            // This code is copied from KLineEdit::setCompletedItems
-            QListWidgetItem *currentItem = completionbox->currentItem();
-
-            QString currentSelection;
-            if (currentItem != 0) {
-                currentSelection = currentItem->text();
-            }
-
-            completionbox->setItems(items);
-            const QList<QListWidgetItem *> matchedItems = completionbox->findItems(currentSelection, Qt::MatchExactly);
-            QListWidgetItem *matchedItem = matchedItems.isEmpty() ? 0 : matchedItems.first();
-
-            if (matchedItem) {
-                const bool blocked = completionbox->blockSignals(true);
-                completionbox->setCurrentItem(matchedItem);
-                completionbox->blockSignals(blocked);
-            } else {
-                completionbox->setCurrentRow(-1);
-            }
-        } else { // completion box not visible yet -> show it
-            if (!txt.isEmpty()) {
-                completionbox->setCancelledText(txt);
-            }
-            completionbox->setItems(items);
-            completionbox->popup();
-        }
-
-        if (autoSuggest()) {
-            int index = items.first().indexOf(txt);
-            QString newText = items.first().mid(index);
-            setUserSelection(false);
-            setCompletedText(newText, true);
-        }
-    } else if (completionbox && completionbox->isVisible()) {
-        completionbox->hide();
-    }
+    return box;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -947,24 +863,23 @@ void KonqComboCompletionBox::setItems(const QStringList &items)
     int rowIndex = 0;
 
     if (count() == 0) {
-        insertStringList(items);
+        for (const QString &text : items) {
+            insertItem(rowIndex++, new KonqListWidgetItem(text));
+        }
     } else {
         //Keep track of whether we need to change anything,
         //so we can avoid a repaint for identical updates,
         //to reduce flicker
         bool dirty = false;
 
-        QStringList::ConstIterator it = items.constBegin();
-        const QStringList::ConstIterator itEnd = items.constEnd();
-
-        for (; it != itEnd; ++it) {
+        for (const QString &text : items) {
             if (rowIndex < count()) {
-                const bool changed = (static_cast<KonqListWidgetItem *>(item(rowIndex)))->reuse(*it);
+                const bool changed = (static_cast<KonqListWidgetItem *>(item(rowIndex)))->reuse(text);
                 dirty = dirty || changed;
             } else {
                 dirty = true;
                 //Inserting an item is a way of making this dirty
-                addItem(new KonqListWidgetItem(*it));
+                addItem(new KonqListWidgetItem(text));
             }
             rowIndex++;
         }
@@ -989,14 +904,3 @@ void KonqComboCompletionBox::setItems(const QStringList &items)
 
     blockSignals(block);
 }
-
-void KonqComboCompletionBox::insertStringList(const QStringList &list, int index)
-{
-    if (index < 0) {
-        index = count();
-    }
-
-    foreach (const QString &text, list) {
-        insertItem(index++, new KonqListWidgetItem(text));
-    }
-}
