@@ -246,7 +246,7 @@ public:
 
     static QList<KonqMainWindow *> *mainWindowList()
     {
-        return s_lstViews;
+        return s_lstMainWindows;
     }
 
     void linkableViewCountChanged();
@@ -305,10 +305,11 @@ public:
     // Not used by konqueror itself; only exists for the Q_PROPERTY,
     // which I guess is used by scripts and plugins...
     QString currentURL() const;
-    void applyWindowSizeFromProfile(const KConfigGroup &profileGroup);
 
     void updateHistoryActions();
 
+    bool isPreloaded() const;
+
     // Public for unit tests
     void prepareForPopupMenu(const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs);
 
@@ -691,7 +692,7 @@ private: // members
     QActionGroup *m_closedItemsGroup;
     QActionGroup *m_sessionsGroup;
 
-    static QList<KonqMainWindow *> *s_lstViews;
+    static QList<KonqMainWindow *> *s_lstMainWindows;
 
     QUrl m_currentDir; // stores current dir for relative URLs whenever applicable
 
