@@ -19,7 +19,7 @@
 
 #include "konqmainwindowfactory.h"
 #include "konqmainwindow.h"
-#include "konqpreloadinghandler.h"
+#include "konqview.h"
 #include "konqsessionmanager.h"
 #include "konqsettingsxt.h"
 #include <KWindowInfo>
@@ -41,6 +41,14 @@ static void abortFullScreenMode()
     }
 }
 
+// Prepare another preloaded window for next time
+static void ensurePreloadedWindow()
+{
+    if (KonqSettings::alwaysHavePreloaded()) {
+        QTimer::singleShot(500, nullptr, []() { new KonqMainWindow(QUrl(QStringLiteral("about:blank"))); });
+    }
+}
+
 KonqMainWindow *KonqMainWindowFactory::createEmptyWindow()
 {
     abortFullScreenMode();
@@ -52,12 +60,21 @@ KonqMainWindow *KonqMainWindowFactory::createEmptyWindow()
         } else { // This should never happen but just to be sure
             return new KonqMainWindow;
         }
-    } else if (KonqMainWindow *mainWindow = KonqPreloadingHandler::self()->takePreloadedWindow()) {
-        qDebug() << "Using preloaded window";
-        KStartupInfo::setWindowStartupId(mainWindow->winId(), KStartupInfo::startupId());
-        mainWindow->reparseConfiguration();
-        return mainWindow;
     }
+
+    // Let's see if we can reuse a preloaded window
+    QList<KonqMainWindow *> *mainWindowList = KonqMainWindow::mainWindowList();
+    if (mainWindowList) {
+        for (KonqMainWindow *win : *mainWindowList) {
+            if (win->isPreloaded()) {
+                qDebug() << "Reusing preloaded window" << win;
+                KStartupInfo::setWindowStartupId(win->winId(), KStartupInfo::startupId());
+                ensurePreloadedWindow();
+                return win;
+            }
+        }
+    }
+    ensurePreloadedWindow();
     return new KonqMainWindow;
 }
 
