@@ -133,9 +133,6 @@ KonqFrameTabs::KonqFrameTabs(QWidget *parent, KonqFrameContainerBase *parentCont
     connect(this, SIGNAL(initiateDrag(QWidget*)),
             SLOT(slotInitiateDrag(QWidget*)));
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-#pragma message("KF5: revert the commit that introduced this line")
-#endif
     tabBar()->installEventFilter(this);
     initPopupMenu();
 }
@@ -614,14 +611,14 @@ KonqFrameBase *KonqFrameTabs::currentTab() const
 bool KonqFrameTabs::eventFilter(QObject *watched, QEvent *event)
 {
     if (KonqSettings::mouseMiddleClickClosesTab()) {
-        KTabBar *bar = qobject_cast<KTabBar *>(tabBar());
+        QTabBar *bar = tabBar();
         if (watched == bar &&
                 (event->type() == QEvent::MouseButtonPress ||
                  event->type() == QEvent::MouseButtonRelease)) {
             QMouseEvent *e = static_cast<QMouseEvent *>(event);
             if (e->button() == Qt::MidButton) {
                 if (event->type() == QEvent::MouseButtonRelease) {
-                    const int index = bar->selectTab(e->pos());
+                    const int index = bar->tabAt(e->pos());
                     slotCloseRequest(widget(index));
                 }
                 e->accept();
