@@ -49,6 +49,7 @@
 #include <QDesktopWidget>
 #include <QStandardPaths>
 #include <KSharedConfig>
+#include <KWindowConfig>
 
 //#define DEBUG_VIEWMGR
 
@@ -951,15 +952,13 @@ void KonqViewManager::loadViewConfigFromGroup(const KConfigGroup &profileGroup,
     }
 
     // Window size
-    if (!m_pMainWindow->initialGeometrySet()) {
-        if (profileGroup.readEntry("FullScreen", false)) {
-            // Full screen on
-            m_pMainWindow->setWindowState(m_pMainWindow->windowState() | Qt::WindowFullScreen);
-        } else {
-            // Full screen off
-            m_pMainWindow->setWindowState(m_pMainWindow->windowState() & ~Qt::WindowFullScreen);
-            m_pMainWindow->applyWindowSizeFromProfile(profileGroup);
-        }
+    if (profileGroup.readEntry("FullScreen", false)) {
+        // Full screen on
+        m_pMainWindow->setWindowState(m_pMainWindow->windowState() | Qt::WindowFullScreen);
+    } else {
+        // Full screen off
+        m_pMainWindow->setWindowState(m_pMainWindow->windowState() & ~Qt::WindowFullScreen);
+        applyWindowSize(profileGroup);
     }
 
     //qDebug() << "done";
@@ -1034,7 +1033,8 @@ void KonqViewManager::emitActivePartChanged()
     m_pMainWindow->slotPartActivated(activePart());
 }
 
-QSize KonqViewManager::readDefaultSize(const KConfigGroup &cfg, QWidget *widget)
+// Read default size from profile (e.g. Width=80%)
+static QSize readDefaultSize(const KConfigGroup &cfg, QWidget *widget)
 {
     QString widthStr = cfg.readEntry("Width");
     QString heightStr = cfg.readEntry("Height");
@@ -1072,6 +1072,15 @@ QSize KonqViewManager::readDefaultSize(const KConfigGroup &cfg, QWidget *widget)
     return QSize(width, height);
 }
 
+void KonqViewManager::applyWindowSize(const KConfigGroup &profileGroup)
+{
+    const QSize size = readDefaultSize(profileGroup, m_pMainWindow); // example: "Width=80%"
+    if (size.isValid()) {
+        m_pMainWindow->resize(size);
+    }
+    KWindowConfig::restoreWindowSize(m_pMainWindow->windowHandle(), profileGroup); // example: "Width 1400=1120"
+}
+
 void KonqViewManager::loadRootItem(const KConfigGroup &cfg, KonqFrameContainerBase *parent,
                                    const QUrl &defaultURL, bool openUrl,
                                    const QUrl &forcedUrl, const QString &forcedService,
